#!/bin/bash
##### Generate input files for scf calculation

# Specify the paths
pw_root="/opt/QE61/bin"
precmd="mpirun -np 4 --map-by core"
OUT_DIR='/home/jyhuang/WS_QE/scratch'
PSEUDO_DIR='/home/jyhuang/WS_QE/pseudo'

rm -rf results
mkdir results

cat <<EOF > "./data/OAl.scf.in"
&CONTROL
  calculation   = 'scf'
  title         = 'O_on_Al(100)'
  restart_mode  = 'from_scratch'
  prefix        = 'OAl'
  outdir        = '${OUT_DIR}'
  pseudo_dir    = '${PSEUDO_DIR}'
/
&SYSTEM
    ibrav     = 0
    celldm(1) = 5.3d0
    nat       = 13
    ntyp      = 2
    ecutwfc   = 16.0d0
    ecutrho   = 160.0d0
    occupations = 'smearing'
    degauss     = 0.03D0
    smearing    = 'mp'
/
&ELECTRONS
    conv_thr    = 1.0d-5
    mixing_mode = 'plain'
    mixing_beta = 0.3d0
/
ATOMIC_SPECIES
Al  27.0  Al.pbe-rrkj.UPF
O   16.0  O.pbe-rrkjus.UPF
ATOMIC_POSITIONS (alat) #atomic positions are specified in units of the lattice parameter
O  1.000 1.000 2.677
Al 0.500 0.500 2.414
Al 1.500 0.500 2.414
Al 0.500 1.500 2.414
Al 1.500 1.500 2.414
Al 0.000 0.000 1.707
Al 1.000 0.000 1.707
Al 0.000 1.000 1.707
Al 1.000 1.000 1.707
Al 0.500 0.500 1.000
Al 1.500 0.500 1.000
Al 0.500 1.500 1.000
Al 1.500 1.500 1.000
K_POINTS { automatic }
2 2 1 1 1 1
CELL_PARAMETERS
   2.00000    0.00000    0.00000
   0.00000    2.00000    0.00000
   0.00000    0.00000    4.50000
EOF

cat <<EOF > "./data/O.scf.in"
&CONTROL
  calculation   = 'scf'
  title         = 'O_atom'
  restart_mode  = 'from_scratch'
  prefix        = 'O'
  outdir        = '${OUT_DIR}'
  pseudo_dir    = '${PSEUDO_DIR}'
/
&SYSTEM
    ibrav     = 0
    celldm(1) = 5.3d0
    nat       = 1
    ntyp      = 1
    ecutwfc   = 16.0d0
    ecutrho   = 160.0d0
    occupations = 'smearing'
    degauss     = 0.03D0
    smearing    = 'mp'
/
&ELECTRONS
    conv_thr    = 1.0d-5
    mixing_mode = 'plain'
    mixing_beta = 0.3d0
/
ATOMIC_SPECIES
O   16.0  O.pbe-rrkjus.UPF
ATOMIC_POSITIONS (alat)
O  1.000 1.000 2.677
K_POINTS { automatic }
2 2 1 1 1 1
CELL_PARAMETERS
   2.00000    0.00000    0.00000
   0.00000    2.00000    0.00000
   0.00000    0.00000    4.50000
EOF

cat <<EOF > "./data/Al.scf.in"
&CONTROL
  calculation   = 'scf'
  title         = 'Al(100)'
  restart_mode  = 'from_scratch'
  prefix        = 'Al'
  outdir        = '${OUT_DIR}'
  pseudo_dir    = '${PSEUDO_DIR}'
/
&SYSTEM
    ibrav     = 0
    celldm(1) = 5.3d0
    nat       = 12
    ntyp      = 1
    ecutwfc   = 16.0d0
    ecutrho   = 160.0d0
    occupations = 'smearing'
    degauss     = 0.03D0
    smearing    = 'mp'
/
&ELECTRONS
    conv_thr    = 1.0d-5
    mixing_mode = 'plain'
    mixing_beta = 0.3d0
/
ATOMIC_SPECIES
Al  27.0  Al.pbe-rrkj.UPF
ATOMIC_POSITIONS (alat)
Al 0.500 0.500 2.414
Al 1.500 0.500 2.414
Al 0.500 1.500 2.414
Al 1.500 1.500 2.414
Al 0.000 0.000 1.707
Al 1.000 0.000 1.707
Al 0.000 1.000 1.707
Al 1.000 1.000 1.707
Al 0.500 0.500 1.000
Al 1.500 0.500 1.000
Al 0.500 1.500 1.000
Al 1.500 1.500 1.000
K_POINTS { automatic }
2 2 1 1 1 1
CELL_PARAMETERS
   2.00000    0.00000    0.00000
   0.00000    2.00000    0.00000
   0.00000    0.00000    4.50000
EOF

##### Input files generated. Now execute!

for PREFIX in Al O OAl; do
echo Now doing $PREFIX ...
${precmd} ${pw_root}/pw.x < ./data/${PREFIX}.scf.in > ./results/$PREFIX.scf.out

##### Now do data postprocessing!
cat <<EOF > "./data/$PREFIX.ppin"
&inputPP
   prefix   = '$PREFIX'
   outdir   = '${OUT_DIR}'
   filplot  = '$PREFIX.charge'
   plot_num = 0
/
EOF

${precmd} ${pw_root}/pp.x < ./data/$PREFIX.ppin > ./results/$PREFIX.ppout
done
echo Done
